@@ -308,8 +308,11 @@ class findpeaks():
                 # Store the score and ranking
                 df['rank'] = 0
                 df['score'] = 0
-                df['rank'].loc[df['peak']] = dfint['rank'].loc[dfint['peak']].values
-                df['score'].loc[df['peak']] = dfint['score'].loc[dfint['peak']].values
+                
+                df['rank'].iloc[result['topology']['max_peaks'][:, 0]] = dfint['rank'].iloc[result['topology']['max_peaks_s'][:, 0]].values
+                df['score'].iloc[result['topology']['max_peaks'][:, 0]] = dfint['score'].iloc[result['topology']['max_peaks_s'][:, 0]].values
+                # df['rank'].loc[df['peak']] = dfint['rank'].loc[dfint['peak']].values
+                # df['score'].loc[df['peak']] = dfint['score'].loc[dfint['peak']].values
 
             # Store in results
             results['df'] = df
@@ -824,6 +827,7 @@ class findpeaks():
         figsize = figsize if figsize is not None else self.args['figsize']
         fig, (ax1, ax2) = plt.subplots(1, 2, figsize=figsize)
 
+        disable = (True if ((verbose==0 or verbose is None) or verbose>3) else False)
         if self.args['type']=='peaks1d':
             # minpers = 0
             min_peaks = self.results['df']['x'].loc[self.results['df']['valley']].values
@@ -834,7 +838,7 @@ class findpeaks():
             y = self.results['df']['y'].values
             x = self.results['df']['x'].values
             idx = np.where(self.results['df']['rank']>0)[0]
-            for i in tqdm(idx):
+            for i in tqdm(idx, disable=disable):
                 ax1.text(x[i], (y[i] + y[i] * 0.01), str(self.results['df']['rank'].iloc[i]), color='b')
 
         else:
@@ -846,7 +850,7 @@ class findpeaks():
             # Plot the detected loci
             if verbose>=3: print('[findpeaks] >Plotting loci of birth..')
             ax1.set_title("Loci of births")
-            for i, homclass in tqdm(enumerate(self.results['groups0'])):
+            for i, homclass in tqdm(enumerate(self.results['groups0']), disable=disable):
                 p_birth, bl, pers, p_death = homclass
                 if (self.limit is None):
                     y, x = p_birth
@@ -870,7 +874,7 @@ class findpeaks():
         x = self.results['persistence']['birth_level'].values
         y = self.results['persistence']['death_level'].values
         plt.plot(x, y, '.', c='b')
-        for i in tqdm(range(0,len(x))):
+        for i in tqdm(range(0,len(x)), disable=disable):
             plt.text(x[i], (y[i] + y[i] * 0.01),  str(i + 1), color='b')
 
         # if verbose>=3: print('[findpeaks] >Plotting Peristence..')
